pub struct HASHER { /* private fields */ }Methods from Deref<Target = RandomState>
Sourcepub fn hash_one<T>(&self, x: T) -> u64
pub fn hash_one<T>(&self, x: T) -> u64
Calculates the hash of a single value. This provides a more convenient (and faster) way to obtain a hash: For example:
Examples
use std::hash::BuildHasher;
use ahash::RandomState;
let hash_builder = RandomState::new();
let hash = hash_builder.hash_one("Some Data");This is similar to:
Examples
use std::hash::{BuildHasher, Hash, Hasher};
use ahash::RandomState;
let hash_builder = RandomState::new();
let mut hasher = hash_builder.build_hasher();
"Some Data".hash(&mut hasher);
let hash = hasher.finish();(Note that these two ways to get a hash may not produce the same value for the same data)
This is intended as a convenience for code which consumes hashes, such
as the implementation of a hash table or in unit tests that check
whether a custom Hash implementation behaves as expected.
This must not be used in any code which creates hashes, such as in an
implementation of Hash. The way to create a combined hash of
multiple values is to call Hash::hash multiple times using the same
Hasher, not to call this method repeatedly and combine the results.